[][src]Module spdkit::common

Modules

de

Generic data structure deserialization framework.

ser

Generic data structure serialization framework.

Macros

anyhow

Construct an ad-hoc error from a string.

bail

Return early with an error.

debug

Logs a message at the debug level.

ensure

Return early with an error if a condition is not satisfied.

error

Logs a message at the error level.

format_err

Construct an ad-hoc error from a string.

forward_to_deserialize_any

Helper macro when implementing the Deserializer part of a new data format for Serde.

info

Logs a message at the info level.

serde_if_integer128

Conditional compilation depending on whether Serde is built with support for 128-bit integers.

trace

Logs a message at the trace level.

warn

Logs a message at the warn level.

Structs

Chain

Iterator of a chain of source errors.

Error

The Error type, a wrapper around a dynamic error type.

Traits

Configure
Context

Provides the context method for Result.

Deserialize

A data structure that can be deserialized from any data format supported by Serde.

Deserializer

A data format that can deserialize any data structure supported by Serde.

FloatIteratorExt
FromParallelIterator

FromParallelIterator implements the creation of a collection from a ParallelIterator. By implementing FromParallelIterator for a given type, you define how it will be created from an iterator.

IndexedParallelIterator

An iterator that supports "random access" to its data, meaning that you can split it at arbitrary indices and draw data from those points.

IntoParallelIterator

IntoParallelIterator implements the conversion to a ParallelIterator.

IntoParallelRefIterator

IntoParallelRefIterator implements the conversion to a ParallelIterator, providing shared references to the data.

IntoParallelRefMutIterator

IntoParallelRefMutIterator implements the conversion to a ParallelIterator, providing mutable references to the data.

Itertools

An Iterator blanket implementation that provides extra adaptors and methods.

ParallelBridge

Conversion trait to convert an Iterator to a ParallelIterator.

ParallelExtend

ParallelExtend extends an existing collection with items from a ParallelIterator.

ParallelIterator

Parallel version of the standard iterator trait.

ParallelSlice

Parallel extensions for slices.

ParallelSliceMut

Parallel extensions for mutable slices.

ParallelString

Parallel extensions for strings.

Serialize

A data structure that can be serialized into any data format supported by Serde.

Serializer

A data format that can serialize any data structure supported by Serde.

Functions

float_ordering_maximize

For sort values in maximum first order.

float_ordering_minimize

For sort values in minimum first order.

Type Definitions

Result

Result<T, Error>

Derive Macros

Deserialize
Serialize