[][src]Struct spdkit::operators::selection::TournamentSelection

pub struct TournamentSelection { /* fields omitted */ }

Divide the populations into multiple parts and select the best one from each part in a deterministic way.

Notes

  • This implementation avoids population members not being sampled, different from the one described in the wikipedia article.

Methods

impl TournamentSelection[src]

pub fn new(n: usize) -> Self[src]

Parameters

  • n: the total number of tournaments