pub struct RunningMean { /* private fields */ }Expand description
Terminates simulation if best solution found so far has no improvement for
n generations.
The running mean termination criterion is fulfilled if the difference
between the best objective value of the current generation and the average
of the best objective values of the last generations is equal to or less
than a given threshold epsilon (Jainet al., 2001)
Implementations